Learn R Programming

echos (version 1.0.3)

summary.tune_esn: Provide a summary of the hyperparameter tuning

Description

Provide a summary of the tuned hyperparameters alpha, rho and tau.

Usage

# S3 method for tune_esn
summary(object, metric = "mse", ...)

Value

Print detailed model summary.

Arguments

object

An object of class tune_esn. The result of a call to tune_esn().

metric

Character value. The metric used to select the best hyperparameter combination (metric = c("mse", "mae").

...

Currently not in use.

See Also

Other base functions: forecast_esn(), is.esn(), is.forecast_esn(), is.tune_esn(), plot.esn(), plot.forecast_esn(), plot.tune_esn(), print.esn(), summary.esn(), train_esn(), tune_esn()

Examples

Run this code
xdata <- as.numeric(AirPassengers)
fit <- tune_esn(
  y = xdata,
  n_ahead = 12,
  n_split = 5,
  alpha = c(0.5, 1),
  rho   = c(1.0),
  tau   = c(0.4),
  inf_crit = "bic"
)

summary(fit)

Run the code above in your browser using DataLab