plot.tune_esn: Plot forecasts from a tuned ESN object
Description
Plot actual values and the point forecasts from the best
hyperparameter combination selected via tune.esn() using the
selected accuracy metric. Forecasts are shown as separate line segments
for each test split, with vertical dashed lines marking the starts of test
windows.
Usage
# S3 method for tune_esn
plot(x, metric = "mse", ...)
Value
Line chart of point forecast and actual values.
Arguments
x
An object of class tune_esn. The result of a call to tune_esn().
metric
Character value. The metric used to select the best hyperparameter combination (metric = c("mse", "mae").