powered by
Provide a summary of the tuned hyperparameters alpha, rho and tau.
alpha
rho
tau
# S3 method for tune_esn summary(object, metric = "mse", ...)
Print detailed model summary.
An object of class tune_esn. The result of a call to tune_esn().
tune_esn
tune_esn()
Character value. The metric used to select the best hyperparameter combination (metric = c("mse", "mae").
metric = c("mse", "mae")
Currently not in use.
Other base functions: forecast_esn(), is.esn(), is.forecast_esn(), is.tune_esn(), plot.esn(), plot.forecast_esn(), plot.tune_esn(), print.esn(), summary.esn(), train_esn(), tune_esn()
forecast_esn()
is.esn()
is.forecast_esn()
is.tune_esn()
plot.esn()
plot.forecast_esn()
plot.tune_esn()
print.esn()
summary.esn()
train_esn()
xdata <- as.numeric(AirPassengers) fit <- tune_esn( y = xdata, n_ahead = 12, n_split = 5, alpha = c(0.5, 1), rho = c(1.0), tau = c(0.4), inf_crit = "bic" ) summary(fit)
Run the code above in your browser using DataLab