A tibble with ten synthetic univariate time series. The dataset is
intended for examples, documentation, and tests in the echos
package. It contains deterministic wave patterns as well as stochastic
benchmark processes.
The dataset contains the following time series:
Square Wave
Sawtooth Wave
Harmonic Wave
Harmonic Wave w/ Trend
Amplitude Modulated Wave
Frequency Modulated Wave
AR(1) Process
MA(2) Process
White Noise Process
Random Walk Process
Usage
data(synthetic_data)Format
An object of class tibble with 2,000 rows and 3 columns:
variable: Unique identifier of the synthetic time series ascharacter.index: Time index asinteger.value: Observed value asnumeric.